Video

Struct Video 

pub struct Video(/* private fields */);

Implementations

Source

impl Video

pub fn new(url_or_id: impl Into<String>) -> Result<Self, VideoError>

Crate Video struct to get info or download with default VideoOptions

pub fn new_with_options( url_or_id: impl Into<String>, options: VideoOptions, ) -> Result<Self, VideoError>

Crate Video struct to get info or download with custom VideoOptions

pub fn get_basic_info(&self) -> Result<VideoInfo, VideoError>

Try to get basic information about video

  • HLS and DashMPD formats excluded!
pub fn get_info(&self) -> Result<VideoInfo, VideoError>

Try to get full information about video

  • HLS and DashMPD formats included!
pub fn stream(&self) -> Result<Box<dyn Stream + Send + Sync>, VideoError>

Try to turn Stream implemented LiveStream or NonLiveStream depend on the video. If function successfully return can download video chunk by chunk

Example
    let video_url = "https://www.youtube.com/watch?v=FZ8BxMU3BYc";

    let video = Video::new(video_url).unwrap();

    let stream = video.stream().unwrap();

    while let Some(chunk) = stream.chunk().unwrap() {
          println!("{:#?}", chunk);
    }
pub async fn stream_with_ffmpeg( &self, ffmpeg_args: Option<FFmpegArgs>, ) -> Result<Box<dyn Stream + Send + Sync>, VideoError>

Try to turn Stream implemented LiveStream or NonLiveStream depend on the video with FFmpegArgs. If function successfully return can download video with applied ffmpeg filters and formats chunk by chunk

Example
    let video_url = "https://www.youtube.com/watch?v=FZ8BxMU3BYc";

    let video = Video::new(video_url).unwrap();

    let stream = video.stream_with_ffmpeg(Some(FFmpegArgs {
           format: Some("mp3".to_string()),
           audio_filter: Some("aresample=48000,asetrate=48000*0.8".to_string()),
           video_filter: Some("eq=brightness=150:saturation=2".to_string()),
       })).unwrap();

    while let Some(chunk) = stream.chunk().unwrap() {
          println!("{:#?}", chunk);
    }
pub fn download<P: AsRef<Path>>(&self, path: P) -> Result<(), VideoError>

Download video directly to the file

pub async fn download_with_ffmpeg<P: AsRef<Path>>( &self, path: P, ffmpeg_args: Option<FFmpegArgs>, ) -> Result<(), VideoError>

Download video with ffmpeg args directly to the file

pub fn get_video_url(&self) -> String

Get video URL

pub fn get_video_id(&self) -> String

Get video id

Methods from Deref<Target = AsyncVideo>

pub async fn get_basic_info(&self) -> Result<VideoInfo, VideoError>

Try to get basic information about video

  • HLS and DashMPD formats excluded!
pub async fn get_info(&self) -> Result<VideoInfo, VideoError>

Try to get full information about video

  • HLS and DashMPD formats included!
pub async fn stream(&self) -> Result<Box<dyn Stream + Send + Sync>, VideoError>

Try to turn Stream implemented LiveStream or NonLiveStream depend on the video. If function successfully return can download video chunk by chunk

Example
    let video_url = "https://www.youtube.com/watch?v=FZ8BxMU3BYc";

    let video = Video::new(video_url).unwrap();

    let stream = video.stream().await.unwrap();

    while let Some(chunk) = stream.chunk().await.unwrap() {
          println!("{:#?}", chunk);
    }
pub async fn stream_with_ffmpeg( &self, ffmpeg_args: Option<FFmpegArgs>, ) -> Result<Box<dyn Stream + Send + Sync>, VideoError>

Try to turn Stream implemented LiveStream or NonLiveStream depend on the video with FFmpegArgs. If function successfully return can download video with applied ffmpeg filters and formats chunk by chunk

Example
    let video_url = "https://www.youtube.com/watch?v=FZ8BxMU3BYc";

    let video = Video::new(video_url).unwrap();

    let stream = video.stream_with_ffmpeg(Some(FFmpegArgs {
           format: Some("mp3".to_string()),
           audio_filter: Some("aresample=48000,asetrate=48000*0.8".to_string()),
           video_filter: Some("eq=brightness=150:saturation=2".to_string()),
       })).await.unwrap();

    while let Some(chunk) = stream.chunk().await.unwrap() {
          println!("{:#?}", chunk);
    }
pub async fn download<P: AsRef<Path>>(&self, path: P) -> Result<(), VideoError>

Download video directly to the file

pub async fn download_with_ffmpeg<P: AsRef<Path>>( &self, path: P, ffmpeg_args: Option<FFmpegArgs>, ) -> Result<(), VideoError>

Download video with ffmpeg args directly to the file

pub fn get_video_url(&self) -> String

Get video URL

pub fn get_video_id(&self) -> String

Get video id