pub enum VideoError {
Show 22 variants
VideoNotFound,
VideoSourceNotFound,
VideoIsPrivate,
VideoPlayerResponseError(String),
Reqwest(Error),
ReqwestMiddleware(Error),
URLParseError(ParseError),
BodyCannotParsed,
FormatNotFound,
InvalidIPv6Format,
InvalidIPv6Subnet,
M3U8ParseError(String),
IsNotPlaylist(String),
PlaylistBodyCannotParsed,
DownloadError(String),
EncryptionError(String),
DecryptionError(String),
HexError(FromHexError),
ChildProcessError(String),
LiveStreamNotSupported,
CookieError,
FFmpeg(String),
}Variants
VideoNotFound
The video not found
VideoSourceNotFound
Video source empty
VideoIsPrivate
Video is private
VideoPlayerResponseError(String)
Video player response errors
Reqwest(Error)
Reqwest error
ReqwestMiddleware(Error)
ReqwestMiddleware error
URLParseError(ParseError)
URL cannot parsed
BodyCannotParsed
Body cannot parsed
FormatNotFound
Format not found
InvalidIPv6Format
Invalid IPv6 format
InvalidIPv6Subnet
Invalid IPv6 subnet
M3U8ParseError(String)
M3U8 parse error
IsNotPlaylist(String)
URL is not playlist
PlaylistBodyCannotParsed
Playlist body cannot parsed
DownloadError(String)
Download error
EncryptionError(String)
Encryption error
DecryptionError(String)
Decryption error
HexError(FromHexError)
Hex encdode error
ChildProcessError(String)
Child process error
LiveStreamNotSupported
Downloading live streams not supported, compile with live feature to enable
CookieError
Provided cookie contains invalid header value characters, an error is returned. Only visible ASCII characters (32-127) are permitted.
FFmpeg(String)
FFmpeg command error