pub struct Video(/* private fields */);Implementations
Sourceimpl Video
impl Video
Sourcepub fn new(url_or_id: impl Into<String>) -> Result<Self, VideoError>
pub fn new(url_or_id: impl Into<String>) -> Result<Self, VideoError>
Crate Video struct to get info or download with default VideoOptions
Sourcepub fn new_with_options(
url_or_id: impl Into<String>,
options: VideoOptions,
) -> Result<Self, VideoError>
pub fn new_with_options( url_or_id: impl Into<String>, options: VideoOptions, ) -> Result<Self, VideoError>
Crate Video struct to get info or download with custom VideoOptions
Sourcepub fn get_basic_info(&self) -> Result<VideoInfo, VideoError>
pub fn get_basic_info(&self) -> Result<VideoInfo, VideoError>
Try to get basic information about video
HLSandDashMPDformats excluded!
Sourcepub fn get_info(&self) -> Result<VideoInfo, VideoError>
pub fn get_info(&self) -> Result<VideoInfo, VideoError>
Try to get full information about video
HLSandDashMPDformats included!
Sourcepub fn stream(&self) -> Result<Box<dyn Stream + Send + Sync>, VideoError>
pub fn stream(&self) -> Result<Box<dyn Stream + Send + Sync>, VideoError>
Try to turn Stream implemented LiveStream or NonLiveStream depend on the video.
If function successfully return can download video chunk by chunk
Example
let video_url = "https://www.youtube.com/watch?v=FZ8BxMU3BYc";
let video = Video::new(video_url).unwrap();
let stream = video.stream().unwrap();
while let Some(chunk) = stream.chunk().unwrap() {
println!("{:#?}", chunk);
}Sourcepub async fn stream_with_ffmpeg(
&self,
ffmpeg_args: Option<FFmpegArgs>,
) -> Result<Box<dyn Stream + Send + Sync>, VideoError>
pub async fn stream_with_ffmpeg( &self, ffmpeg_args: Option<FFmpegArgs>, ) -> Result<Box<dyn Stream + Send + Sync>, VideoError>
Try to turn Stream implemented LiveStream or NonLiveStream depend on the video with FFmpegArgs.
If function successfully return can download video with applied ffmpeg filters and formats chunk by chunk
Example
let video_url = "https://www.youtube.com/watch?v=FZ8BxMU3BYc";
let video = Video::new(video_url).unwrap();
let stream = video.stream_with_ffmpeg(Some(FFmpegArgs {
format: Some("mp3".to_string()),
audio_filter: Some("aresample=48000,asetrate=48000*0.8".to_string()),
video_filter: Some("eq=brightness=150:saturation=2".to_string()),
})).unwrap();
while let Some(chunk) = stream.chunk().unwrap() {
println!("{:#?}", chunk);
}Sourcepub fn download<P: AsRef<Path>>(&self, path: P) -> Result<(), VideoError>
pub fn download<P: AsRef<Path>>(&self, path: P) -> Result<(), VideoError>
Download video directly to the file
Sourcepub async fn download_with_ffmpeg<P: AsRef<Path>>(
&self,
path: P,
ffmpeg_args: Option<FFmpegArgs>,
) -> Result<(), VideoError>
pub async fn download_with_ffmpeg<P: AsRef<Path>>( &self, path: P, ffmpeg_args: Option<FFmpegArgs>, ) -> Result<(), VideoError>
Download video with ffmpeg args directly to the file
Sourcepub fn get_video_url(&self) -> String
pub fn get_video_url(&self) -> String
Get video URL
Sourcepub fn get_video_id(&self) -> String
pub fn get_video_id(&self) -> String
Get video id
Methods from Deref<Target = AsyncVideo>
Sourcepub async fn get_basic_info(&self) -> Result<VideoInfo, VideoError>
pub async fn get_basic_info(&self) -> Result<VideoInfo, VideoError>
Try to get basic information about video
HLSandDashMPDformats excluded!
Sourcepub async fn get_info(&self) -> Result<VideoInfo, VideoError>
pub async fn get_info(&self) -> Result<VideoInfo, VideoError>
Try to get full information about video
HLSandDashMPDformats included!
Sourcepub async fn stream(&self) -> Result<Box<dyn Stream + Send + Sync>, VideoError>
pub async fn stream(&self) -> Result<Box<dyn Stream + Send + Sync>, VideoError>
Try to turn Stream implemented LiveStream or NonLiveStream depend on the video.
If function successfully return can download video chunk by chunk
Example
let video_url = "https://www.youtube.com/watch?v=FZ8BxMU3BYc";
let video = Video::new(video_url).unwrap();
let stream = video.stream().await.unwrap();
while let Some(chunk) = stream.chunk().await.unwrap() {
println!("{:#?}", chunk);
}Sourcepub async fn stream_with_ffmpeg(
&self,
ffmpeg_args: Option<FFmpegArgs>,
) -> Result<Box<dyn Stream + Send + Sync>, VideoError>
pub async fn stream_with_ffmpeg( &self, ffmpeg_args: Option<FFmpegArgs>, ) -> Result<Box<dyn Stream + Send + Sync>, VideoError>
Try to turn Stream implemented LiveStream or NonLiveStream depend on the video with FFmpegArgs.
If function successfully return can download video with applied ffmpeg filters and formats chunk by chunk
Example
let video_url = "https://www.youtube.com/watch?v=FZ8BxMU3BYc";
let video = Video::new(video_url).unwrap();
let stream = video.stream_with_ffmpeg(Some(FFmpegArgs {
format: Some("mp3".to_string()),
audio_filter: Some("aresample=48000,asetrate=48000*0.8".to_string()),
video_filter: Some("eq=brightness=150:saturation=2".to_string()),
})).await.unwrap();
while let Some(chunk) = stream.chunk().await.unwrap() {
println!("{:#?}", chunk);
}Sourcepub async fn download<P: AsRef<Path>>(&self, path: P) -> Result<(), VideoError>
pub async fn download<P: AsRef<Path>>(&self, path: P) -> Result<(), VideoError>
Download video directly to the file
Sourcepub async fn download_with_ffmpeg<P: AsRef<Path>>(
&self,
path: P,
ffmpeg_args: Option<FFmpegArgs>,
) -> Result<(), VideoError>
pub async fn download_with_ffmpeg<P: AsRef<Path>>( &self, path: P, ffmpeg_args: Option<FFmpegArgs>, ) -> Result<(), VideoError>
Download video with ffmpeg args directly to the file
Sourcepub fn get_video_url(&self) -> String
pub fn get_video_url(&self) -> String
Get video URL
Sourcepub fn get_video_id(&self) -> String
pub fn get_video_id(&self) -> String
Get video id